
set -euo pipefail

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
ARCH=$(uname -m)
PROJECT="getpkg"
OUTPUT="${SCRIPT_DIR}/output"


function heading() {
  # print a heading with a line of dashe
  echo "--------------------------------"
  echo "$1"
  echo "--------------------------------"
}

#--------------------------------------------------------------------------------
heading "Publishing ${PROJECT}"

function die() {
    heading "error: $1"
    exit 1
}

[[ -n $SOS_WRITE_TOKEN ]] || die "SOS_WRITE_TOKEN not specified"

# clear output dir
rm -rf "${OUTPUT}" 
mkdir -p "${OUTPUT}"


#--------------------------------------------------------------------------------
heading "Building ${PROJECT}"

# build release version
export CMAKE_BUILD_TYPE="Release"
"${SCRIPT_DIR}/build.sh"
[ -f "${OUTPUT}/${PROJECT}" ] || die "Build failed."

#--------------------------------------------------------------------------------
SOS="${SCRIPT_DIR}/../sos/sos"
[ -f "${SOS}" ] || die "Failed to find sos"

#--------------------------------------------------------------------------------
heading "Uploading ${PROJECT} to getbin.xyz"

# upload arch-specific binary
"${SOS}" upload "getbin.xyz" "${OUTPUT}/${PROJECT}" "${PROJECT}:latest-${ARCH}"

# upload generic install script (ok if multiple times as we iterate through arch's)
"${SOS}" upload "getbin.xyz" "${SCRIPT_DIR}/install.sh" "${PROJECT}-install:latest"

#--------------------------------------------------------------------------------
heading "Publishing ${PROJECT} as tool to getpkg:${ARCH} (on getpkg.xyz)"

TOOLDIR="${OUTPUT}/tool"
mkdir "${TOOLDIR}"
cp "${OUTPUT}/${PROJECT}" "${TOOLDIR}/${PROJECT}"
"${OUTPUT}/${PROJECT}" publish "getpkg:${ARCH}" "${TOOLDIR}"
